@@ -6,7 +6,6 @@
 
 
 import unittest
-import doctest
 
 import sys
 import os
@@ -22,7 +21,6 @@ import gevent.monkey
 from gevent.socket import wait_read
 
 import xnet.tools
-from xnet.debug import pdb
 
 
 gevent.monkey.patch_all(thread=False)
@@ -124,12 +122,14 @@ def top_usage():
     return output
 
 
-def print_error(errval):
-    errmsg = str(errval)
+def print_error(a):
+    errmsg = str(a.error)
     if not errmsg.strip():
         errmsg = 'no-error-set\n'
     if not errmsg[-1] == '\n':
         errmsg += '\n'
+    item = str(a._item).strip()
+    errmsg = item + ' ' + errmsg
     sys.stderr.write(errmsg)
 
 
@@ -162,7 +162,7 @@ def _get_output_filepath(a, base):
     # which should not affect the file system path
     # where the output file is created.
     #
-    item = str(a._item)
+    item = str(a._item).strip()
     item = item.replace('/', '__')
     item = item.replace('\\', '--')
     path = base + item
@@ -186,14 +186,14 @@ def repeaterator(it, count):
             yield item
         if count > 0:
             count -= 1
-        
+
 
 def run(ToolImplementation, tool_reads_stdin=False):
     try:
         return _run(ToolImplementation, tool_reads_stdin)
     except KeyboardInterrupt:
         return 1
-    
+
 
 def _run(ToolImplementation, tool_reads_stdin):
     '''
@@ -281,7 +281,7 @@ def _run(ToolImplementation, tool_reads_stdin):
         if sleeptime > 0:
             gevent.sleep(sleeptime)
         if not g.ready():
-            gevent.kill(g)
+            gevent.kill(g, xnet.tools.WaitTimeout)
             g.join()
 
     inputchain = ToolImplementation.__massage__(inputchain)
@@ -299,6 +299,7 @@ def _run(ToolImplementation, tool_reads_stdin):
         inputchain = repeaterator(inputchain, _repeat)
 
     for (i, line) in enumerate(inputchain):
+        line = line.strip()
         action = ToolImplementation(opt, **kwargs)
         pool.wait_available()
         if _wait:
@@ -306,6 +307,9 @@ def _run(ToolImplementation, tool_reads_stdin):
         g = pool.spawn(action, line, inputchain)
         g.action = action
         greenlets.append(g)
+        #
+        # Timeout seems unreliable on debian squeeze, use waitkill instead.
+        #
         if _wait:
             wkpool.wait_available()
             wk = wkpool.spawn(waitkill, g, killtime)
@@ -327,7 +331,6 @@ def _run(ToolImplementation, tool_reads_stdin):
             gevent.sleep(_this_interval)
         _t = time.time()
 
-
     if wkpool:
         wkpool.join()
     gevent.joinall(greenlets) #, timeout=timeout)
@@ -350,14 +353,13 @@ def _run(ToolImplementation, tool_reads_stdin):
         output_action_result(action, opt, _outfile)
         del action
 
-
 def output_action_result(a, opt, _outfile):
     outfile = _outfile
     if opt.split_output:
         path = _get_output_filepath(a, opt.split_output)
         outfile = open(path, 'wb')
     if not a.error is None:
-        print_error(a.error)
+        print_error(a)
     elif not a.finished:
         if not opt.supress_timeout:
             msg = a.__timeout__()
@@ -450,8 +452,8 @@ def main():
                     print errmsg
                     sys.exit(1)
                 ToolImplementation = val
-         
-    if not ToolImplementation:    
+
+    if not ToolImplementation:
         if toolname == 'iprange':
             from xnet.tools.iprange import IPRangeTool as ToolImplementation
 
